# Exergi Python Package
This project is a part of the Datadriven Production & Distribution Department 

#### -- Project Status: [Active]

## Project Intro/Objective
The purpose of this project is to gather all exergi specific code in one repo and share it easily across the organisation. 

## Modules
* AWS S3. Import and exports files to S3
* AWS RDS for PostgreSQL. Connect, imports and exports data to RDS PostgreSQL

## Installation
A step by step series of examples that tell you how to get a development env running

Say what the step will be

```
pip install exergi
```

To update exergi package please use 

```
pip install --upgrade exergi 
```

## Featured Files
* --
* --
* --

## Contributing Members

**Leads : [Kasper Janehag](https://gitlab.stockholmexergi.io/kasper.janehag)**

## Members:

|Name     |  Role  | 
|---------|-----------------|
|[Kasper Janehag] | Data Scientist        |
|[Johan Wållgren] | Data Scientist         |